

.. _sardana-devel-macro-examples:

==============
Macro examples
==============

.. toctree::
    :maxdepth: 2
    
    Specifying macro parameters <macro_parameter_examples>
    Calling sub-macros <macro_call_examples>
    Plotting <macro_plotting_examples>
    Asking user input <macro_input_examples>
